.. vim: set fileencoding=utf-8 :
.. Andre Anjos <andre.anjos@idiap.ch>
.. Mon  4 Nov 20:58:04 2013 CET
..
.. Copyright (C) 2011-2013 Idiap Research Institute, Martigny, Switzerland

.. _bob.measure:

=======================
 Bob's Metric Routines
=======================

This module contains routines for assessing performance on machine learning and pattern recognition applications and for generating performance plots.

Documentation
-------------

.. toctree::
   :maxdepth: 2

   guide
   py_api

TODO
----

.. todolist::


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: links.rst
